summaryrefslogtreecommitdiff
path: root/sqlbox/lib.php
diff options
context:
space:
mode:
authorJan Klemkow <j.klemkow@wemelug.de>2012-10-09 15:28:22 +0200
committerJan Klemkow <j.klemkow@wemelug.de>2012-10-09 15:28:22 +0200
commit5c7511c7c64f62f44244ba1c9f1aac9952c564e1 (patch)
tree9f10a75a48b2d7df333ada2f6d750dddf430bafb /sqlbox/lib.php
parent459313e56b0653e4709694a7e86afc11be514097 (diff)
downloadsqltutor-plugin-5c7511c7c64f62f44244ba1c9f1aac9952c564e1.tar.gz
sqltutor-plugin-5c7511c7c64f62f44244ba1c9f1aac9952c564e1.tar.bz2
sqltutor-plugin-5c7511c7c64f62f44244ba1c9f1aac9952c564e1.zip
Rename 'newmodule' into sqlbox in all files.
Diffstat (limited to 'sqlbox/lib.php')
-rw-r--r--sqlbox/lib.php136
1 files changed, 68 insertions, 68 deletions
diff --git a/sqlbox/lib.php b/sqlbox/lib.php
index d84e480..fe3cc17 100644
--- a/sqlbox/lib.php
+++ b/sqlbox/lib.php
@@ -16,16 +16,16 @@
// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
/**
* Library of interface functions and constants for module newmodule
*
* All the core Moodle functions, neeeded to allow the module to work
* integrated in Moodle should be placed here.
* All the newmodule specific functions, needed to implement all the module
* logic, should go to locallib.php. This will help to save some memory when
* Moodle is performing actions across all modules.
*
* @package mod
- * @subpackage newmodule
+ * @subpackage sqlbox
* @copyright 2011 Your Name
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -46,7 +46,7 @@ defined('MOODLE_INTERNAL') || die();
* @param string $feature FEATURE_xx constant for requested feature
* @return mixed true if the feature is supported, null if unknown
*/
-function newmodule_supports($feature) {
+function sqlbox_supports($feature) {
switch($feature) {
case FEATURE_MOD_INTRO: return true;
default: return null;
@@ -54,51 +54,51 @@ function newmodule_supports($feature) {
}
/**
* Saves a new instance of the newmodule into the database
*
* Given an object containing all the necessary data,
* (defined by the form in mod_form.php) this function
* will create a new instance and return the id number
* of the new instance.
*
* @param object $newmodule An object from the form in mod_form.php
* @param mod_newmodule_mod_form $mform
* @return int The id of the newly inserted newmodule record
*/
-function newmodule_add_instance(stdClass $newmodule, mod_newmodule_mod_form $mform = null) {
+function sqlbox_add_instance(stdClass $sqlbox, mod_sqlbox_mod_form $mform = null) {
global $DB;
- $newmodule->timecreated = time();
+ $sqlbox->timecreated = time();
# You may have to add extra stuff in here #
- return $DB->insert_record('newmodule', $newmodule);
+ return $DB->insert_record('sqlbox', $sqlbox);
}
/**
* Updates an instance of the newmodule in the database
*
* Given an object containing all the necessary data,
* (defined by the form in mod_form.php) this function
* will update an existing instance with new data.
*
* @param object $newmodule An object from the form in mod_form.php
* @param mod_newmodule_mod_form $mform
* @return boolean Success/Fail
*/
-function newmodule_update_instance(stdClass $newmodule, mod_newmodule_mod_form $mform = null) {
+function sqlbox_update_instance(stdClass $sqlbox, mod_sqlbox_mod_form $mform = null) {
global $DB;
- $newmodule->timemodified = time();
- $newmodule->id = $newmodule->instance;
+ $sqlbox->timemodified = time();
+ $sqlbox->id = $sqlbox->instance;
# You may have to add extra stuff in here #
- return $DB->update_record('newmodule', $newmodule);
+ return $DB->update_record('sqlbox', $sqlbox);
}
/**
* Removes an instance of the newmodule from the database
*
* Given an ID of an instance of this module,
* this function will permanently delete the instance
@@ -107,16 +107,16 @@ function newmodule_update_instance(stdClass $newmodule, mod_newmodule_mod_form $
* @param int $id Id of the module instance
* @return boolean Success/Failure
*/
-function newmodule_delete_instance($id) {
+function sqlbox_delete_instance($id) {
global $DB;
- if (! $newmodule = $DB->get_record('newmodule', array('id' => $id))) {
+ if (! $sqlbox = $DB->get_record('sqlbox', array('id' => $id))) {
return false;
}
# Delete any dependent records here #
- $DB->delete_records('newmodule', array('id' => $newmodule->id));
+ $DB->delete_records('sqlbox', array('id' => $sqlbox->id));
return true;
}
@@ -130,7 +130,7 @@ function newmodule_delete_instance($id) {
*
* @return stdClass|null
*/
-function newmodule_user_outline($course, $user, $mod, $newmodule) {
+function sqlbox_user_outline($course, $user, $mod, $sqlbox) {
$return = new stdClass();
$return->time = 0;
@@ -145,20 +145,20 @@ function newmodule_user_outline($course, $user, $mod, $newmodule) {
* @param stdClass $course the current course record
* @param stdClass $user the record of the user we are generating report for
* @param cm_info $mod course module info
* @param stdClass $newmodule the module instance record
* @return void, is supposed to echp directly
*/
-function newmodule_user_complete($course, $user, $mod, $newmodule) {
+function sqlbox_user_complete($course, $user, $mod, $sqlbox) {
}
/**
* Given a course and a time, this module should find recent activity
* that has occurred in newmodule activities and print it out.
* Return true if there was output, or false is there was none.
*
* @return boolean
*/
-function newmodule_print_recent_activity($course, $viewfullnames, $timestart) {
+function sqlbox_print_recent_activity($course, $viewfullnames, $timestart) {
return false; // True if anything was printed, otherwise false
}
@@ -167,7 +167,7 @@ function newmodule_print_recent_activity($course, $viewfullnames, $timestart) {
*
* This callback function is supposed to populate the passed array with
* custom activity records. These records are then rendered into HTML via
- * {@link newmodule_print_recent_mod_activity()}.
+ * {@link sqlbox_print_recent_mod_activity()}.
*
* @param array $activities sequentially indexed array of objects with the 'cmid' property
* @param int $index the index in the $activities to use for the next record
@@ -178,15 +178,15 @@ function newmodule_print_recent_activity($course, $viewfullnames, $timestart) {
* @param int $groupid check for a particular group's activity only, defaults to 0 (all groups)
* @return void adds items into $activities and increases $index
*/
-function newmodule_get_recent_mod_activity(&$activities, &$index, $timestart, $courseid, $cmid, $userid=0, $groupid=0) {
+function sqlbox_get_recent_mod_activity(&$activities, &$index, $timestart, $courseid, $cmid, $userid=0, $groupid=0) {
}
/**
- * Prints single activity item prepared by {@see newmodule_get_recent_mod_activity()}
+ * Prints single activity item prepared by {@see sqlbox_get_recent_mod_activity()}
* @return void
*/
-function newmodule_print_recent_mod_activity($activity, $courseid, $detail, $modnames, $viewfullnames) {
+function sqlbox_print_recent_mod_activity($activity, $courseid, $detail, $modnames, $viewfullnames) {
}
/**
@@ -197,7 +197,7 @@ function newmodule_print_recent_mod_activity($activity, $courseid, $detail, $mod
* @return boolean
* @todo Finish documenting this function
**/
-function newmodule_cron () {
+function sqlbox_cron () {
return true;
}
@@ -207,7 +207,7 @@ function newmodule_cron () {
* @example return array('moodle/site:accessallgroups');
* @return array
*/
-function newmodule_get_extra_capabilities() {
+function sqlbox_get_extra_capabilities() {
return array();
}
@@ -216,21 +216,21 @@ function newmodule_get_extra_capabilities() {
////////////////////////////////////////////////////////////////////////////////
/**
* Is a given scale used by the instance of newmodule?
*
* This function returns if a scale is being used by one newmodule
* if it has support for grading and scales. Commented code should be
* modified if necessary. See forum, glossary or journal modules
* as reference.
*
* @param int $newmoduleid ID of an instance of this module
* @return bool true if the scale is used by the given newmodule instance
*/
-function newmodule_scale_used($newmoduleid, $scaleid) {
+function sqlbox_scale_used($sqlboxid, $scaleid) {
global $DB;
/** @example */
- if ($scaleid and $DB->record_exists('newmodule', array('id' => $newmoduleid, 'grade' => -$scaleid))) {
+ if ($scaleid and $DB->record_exists('sqlbox', array('id' => $sqlboxid, 'grade' => -$scaleid))) {
return true;
} else {
return false;
@@ -238,18 +238,18 @@ function newmodule_scale_used($newmoduleid, $scaleid) {
}
/**
* Checks if scale is being used by any instance of newmodule.
*
* This is used to find out if scale used anywhere.
*
* @param $scaleid int
* @return boolean true if the scale is used by any newmodule instance
*/
-function newmodule_scale_used_anywhere($scaleid) {
+function sqlbox_scale_used_anywhere($scaleid) {
global $DB;
/** @example */
- if ($scaleid and $DB->record_exists('newmodule', array('grade' => -$scaleid))) {
+ if ($scaleid and $DB->record_exists('sqlbox', array('grade' => -$scaleid))) {
return true;
} else {
return false;
@@ -257,44 +257,44 @@ function newmodule_scale_used_anywhere($scaleid) {
}
/**
* Creates or updates grade item for the give newmodule instance
*
* Needed by grade_update_mod_grades() in lib/gradelib.php
*
* @param stdClass $newmodule instance object with extra cmidnumber and modname property
* @return void
*/
-function newmodule_grade_item_update(stdClass $newmodule) {
+function sqlbox_grade_item_update(stdClass $sqlbox) {
global $CFG;
require_once($CFG->libdir.'/gradelib.php');
/** @example */
$item = array();
- $item['itemname'] = clean_param($newmodule->name, PARAM_NOTAGS);
+ $item['itemname'] = clean_param($sqlbox->name, PARAM_NOTAGS);
$item['gradetype'] = GRADE_TYPE_VALUE;
- $item['grademax'] = $newmodule->grade;
+ $item['grademax'] = $sqlbox->grade;
$item['grademin'] = 0;
- grade_update('mod/newmodule', $newmodule->course, 'mod', 'newmodule', $newmodule->id, 0, null, $item);
+ grade_update('mod/sqlbox', $sqlbox->course, 'mod', 'sqlbox', $sqlbox->id, 0, null, $item);
}
/**
* Update newmodule grades in the gradebook
*
* Needed by grade_update_mod_grades() in lib/gradelib.php
*
* @param stdClass $newmodule instance object with extra cmidnumber and modname property
* @param int $userid update grade of specific user only, 0 means all participants
* @return void
*/
-function newmodule_update_grades(stdClass $newmodule, $userid = 0) {
+function sqlbox_update_grades(stdClass $sqlbox, $userid = 0) {
global $CFG, $DB;
require_once($CFG->libdir.'/gradelib.php');
/** @example */
$grades = array(); // populate array of grade objects indexed by userid
- grade_update('mod/newmodule', $newmodule->course, 'mod', 'newmodule', $newmodule->id, 0, $grades);
+ grade_update('mod/sqlbox', $sqlbox->course, 'mod', 'sqlbox', $sqlbox->id, 0, $grades);
}
////////////////////////////////////////////////////////////////////////////////
@@ -312,14 +312,14 @@ function newmodule_update_grades(stdClass $newmodule, $userid = 0) {
* @param stdClass $context
* @return array of [(string)filearea] => (string)description
*/
-function newmodule_get_file_areas($course, $cm, $context) {
+function sqlbox_get_file_areas($course, $cm, $context) {
return array();
}
/**
* File browsing support for newmodule file areas
*
- * @package mod_newmodule
+ * @package mod_sqlbox
* @category files
*
* @param file_browser $browser
@@ -333,25 +333,25 @@ function newmodule_get_file_areas($course, $cm, $context) {
* @param string $filename
* @return file_info instance or null if not found
*/
-function newmodule_get_file_info($browser, $areas, $course, $cm, $context, $filearea, $itemid, $filepath, $filename) {
+function sqlbox_get_file_info($browser, $areas, $course, $cm, $context, $filearea, $itemid, $filepath, $filename) {
return null;
}
/**
* Serves the files from the newmodule file areas
*
- * @package mod_newmodule
+ * @package mod_sqlbox
* @category files
*
* @param stdClass $course the course object
* @param stdClass $cm the course module object
* @param stdClass $context the newmodule's context
* @param string $filearea the name of the file area
* @param array $args extra arguments (itemid, path)
* @param bool $forcedownload whether or not force download
* @param array $options additional options affecting the file serving
*/
-function newmodule_pluginfile($course, $cm, $context, $filearea, array $args, $forcedownload, array $options=array()) {
+function sqlbox_pluginfile($course, $cm, $context, $filearea, array $args, $forcedownload, array $options=array()) {
global $DB, $CFG;
if ($context->contextlevel != CONTEXT_MODULE) {
@@ -368,26 +368,26 @@ function newmodule_pluginfile($course, $cm, $context, $filearea, array $args, $f
////////////////////////////////////////////////////////////////////////////////
/**
* Extends the global navigation tree by adding newmodule nodes if there is a relevant content
*
* This can be called by an AJAX request so do not rely on $PAGE as it might not be set up properly.
*
* @param navigation_node $navref An object representing the navigation tree node of the newmodule module instance
* @param stdClass $course
* @param stdClass $module
* @param cm_info $cm
*/
-function newmodule_extend_navigation(navigation_node $navref, stdclass $course, stdclass $module, cm_info $cm) {
+function sqlbox_extend_navigation(navigation_node $navref, stdclass $course, stdclass $module, cm_info $cm) {
}
/**
* Extends the settings navigation with the newmodule settings
*
* This function is called when the context for the page is a newmodule module. This is not called by AJAX
* so it is safe to rely on the $PAGE.
*
* @param settings_navigation $settingsnav {@link settings_navigation}
- * @param navigation_node $newmodulenode {@link navigation_node}
+ * @param navigation_node $sqlboxnode {@link navigation_node}
*/
-function newmodule_extend_settings_navigation(settings_navigation $settingsnav, navigation_node $newmodulenode=null) {
+function sqlbox_extend_settings_navigation(settings_navigation $settingsnav, navigation_node $sqlboxnode=null) {
}
@@ -16,16 +16,16 @@
// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
/**
- * Library of interface functions and constants for module newmodule
+ * Library of interface functions and constants for module sqlbox
*
* All the core Moodle functions, neeeded to allow the module to work
@@ -16,16 +16,16 @@
* All the core Moodle functions, neeeded to allow the module to work
* integrated in Moodle should be placed here.
- * All the newmodule specific functions, needed to implement all the module
+ * All the sqlbox specific functions, needed to implement all the module
* logic, should go to locallib.php. This will help to save some memory when
* Moodle is performing actions across all modules.
@@ -54,51 +54,51 @@ function newmodule_supports($feature) {
}
/**
- * Saves a new instance of the newmodule into the database
+ * Saves a new instance of the sqlbox into the database
*
* Given an object containing all the necessary data,
@@ -54,51 +54,51 @@ function newmodule_supports($feature) {
* of the new instance.
*
- * @param object $newmodule An object from the form in mod_form.php
- * @param mod_newmodule_mod_form $mform
- * @return int The id of the newly inserted newmodule record
+ * @param object $sqlbox An object from the form in mod_form.php
+ * @param mod_sqlbox_mod_form $mform
+ * @return int The id of the newly inserted sqlbox record
*/
@@ -54,51 +54,51 @@ function newmodule_supports($feature) {
}
/**
- * Updates an instance of the newmodule in the database
+ * Updates an instance of the sqlbox in the database
*
* Given an object containing all the necessary data,
@@ -54,51 +54,51 @@ function newmodule_supports($feature) {
* will update an existing instance with new data.
*
- * @param object $newmodule An object from the form in mod_form.php
- * @param mod_newmodule_mod_form $mform
+ * @param object $sqlbox An object from the form in mod_form.php
+ * @param mod_sqlbox_mod_form $mform
* @return boolean Success/Fail
*/
@@ -54,51 +54,51 @@ function newmodule_supports($feature) {
}
/**
- * Removes an instance of the newmodule from the database
+ * Removes an instance of the sqlbox from the database
*
* Given an ID of an instance of this module,
@@ -145,20 +145,20 @@ function newmodule_user_outline($course, $user, $mod, $newmodule) {
* @param stdClass $user the record of the user we are generating report for
* @param cm_info $mod course module info
- * @param stdClass $newmodule the module instance record
+ * @param stdClass $sqlbox the module instance record
* @return void, is supposed to echp directly
*/
@@ -145,20 +145,20 @@ function newmodule_user_outline($course, $user, $mod, $newmodule) {
/**
* Given a course and a time, this module should find recent activity
- * that has occurred in newmodule activities and print it out.
+ * that has occurred in sqlbox activities and print it out.
* Return true if there was output, or false is there was none.
*
@@ -216,21 +216,21 @@ function newmodule_get_extra_capabilities() {
////////////////////////////////////////////////////////////////////////////////
/**
- * Is a given scale used by the instance of newmodule?
+ * Is a given scale used by the instance of sqlbox?
*
@@ -216,21 +216,21 @@ function newmodule_get_extra_capabilities() {
*
- * This function returns if a scale is being used by one newmodule
+ * This function returns if a scale is being used by one sqlbox
* if it has support for grading and scales. Commented code should be
* modified if necessary. See forum, glossary or journal modules
@@ -216,21 +216,21 @@ function newmodule_get_extra_capabilities() {
* as reference.
*
- * @param int $newmoduleid ID of an instance of this module
- * @return bool true if the scale is used by the given newmodule instance
+ * @param int $sqlboxid ID of an instance of this module
+ * @return bool true if the scale is used by the given sqlbox instance
*/
@@ -238,18 +238,18 @@ function newmodule_scale_used($newmoduleid, $scaleid) {
}
/**
- * Checks if scale is being used by any instance of newmodule.
+ * Checks if scale is being used by any instance of sqlbox.
*
* This is used to find out if scale used anywhere.
@@ -238,18 +238,18 @@ function newmodule_scale_used($newmoduleid, $scaleid) {
*
* @param $scaleid int
- * @return boolean true if the scale is used by any newmodule instance
+ * @return boolean true if the scale is used by any sqlbox instance
*/
@@ -257,44 +257,44 @@ function newmodule_scale_used_anywhere($scaleid) {
}
/**
- * Creates or updates grade item for the give newmodule instance
+ * Creates or updates grade item for the give sqlbox instance
*
* Needed by grade_update_mod_grades() in lib/gradelib.php
@@ -257,44 +257,44 @@ function newmodule_scale_used_anywhere($scaleid) {
* Needed by grade_update_mod_grades() in lib/gradelib.php
*
- * @param stdClass $newmodule instance object with extra cmidnumber and modname property
+ * @param stdClass $sqlbox instance object with extra cmidnumber and modname property
* @return void
*/
@@ -257,44 +257,44 @@ function newmodule_scale_used_anywhere($scaleid) {
}
/**
- * Update newmodule grades in the gradebook
+ * Update sqlbox grades in the gradebook
*
* Needed by grade_update_mod_grades() in lib/gradelib.php
@@ -257,44 +257,44 @@ function newmodule_scale_used_anywhere($scaleid) {
* Needed by grade_update_mod_grades() in lib/gradelib.php
*
- * @param stdClass $newmodule instance object with extra cmidnumber and modname property
+ * @param stdClass $sqlbox instance object with extra cmidnumber and modname property
* @param int $userid update grade of specific user only, 0 means all participants
* @return void
@@ -312,14 +312,14 @@ function newmodule_update_grades(stdClass $newmodule, $userid = 0) {
}
/**
- * File browsing support for newmodule file areas
+ * File browsing support for sqlbox file areas
*
@@ -333,25 +333,25 @@ function newmodule_get_file_areas($course, $cm, $context) {
}
/**
- * Serves the files from the newmodule file areas
+ * Serves the files from the sqlbox file areas
*
@@ -333,25 +333,25 @@ function newmodule_get_file_areas($course, $cm, $context) {
* @param stdClass $course the course object
* @param stdClass $cm the course module object
- * @param stdClass $context the newmodule's context
+ * @param stdClass $context the sqlbox's context
* @param string $filearea the name of the file area
* @param array $args extra arguments (itemid, path)
@@ -368,26 +368,26 @@ function newmodule_pluginfile($course, $cm, $context, $filearea, array $args, $f
////////////////////////////////////////////////////////////////////////////////
/**
- * Extends the global navigation tree by adding newmodule nodes if there is a relevant content
+ * Extends the global navigation tree by adding sqlbox nodes if there is a relevant content
*
* This can be called by an AJAX request so do not rely on $PAGE as it might not be set up properly.
@@ -368,26 +368,26 @@ function newmodule_pluginfile($course, $cm, $context, $filearea, array $args, $f
* This can be called by an AJAX request so do not rely on $PAGE as it might not be set up properly.
*
- * @param navigation_node $navref An object representing the navigation tree node of the newmodule module instance
+ * @param navigation_node $navref An object representing the navigation tree node of the sqlbox module instance
* @param stdClass $course
* @param stdClass $module
@@ -368,26 +368,26 @@ function newmodule_pluginfile($course, $cm, $context, $filearea, array $args, $f
}
/**
- * Extends the settings navigation with the newmodule settings
+ * Extends the settings navigation with the sqlbox settings
*
@@ -368,26 +368,26 @@ function newmodule_pluginfile($course, $cm, $context, $filearea, array $args, $f
*
- * This function is called when the context for the page is a newmodule module. This is not called by AJAX
+ * This function is called when the context for the page is a sqlbox module. This is not called by AJAX
* so it is safe to rely on the $PAGE.
*